Inference on the unconditional Granger-causality spectrum is provided generating bootstrap time series by the stationary boostrap of Politis and Romano (1994). For computational details we refer to Ding et al. (2006) and Farne' and Montanari (2018).
Granger.inference.unconditional(x, y, ic.chosen = "SC",
max.lag = min(4, length(x) - 1), plot = F, type.chosen = "none",
p = 0, nboots = 1000, conf = 0.95, bp = NULL, ts_boot = 1)univariate time series.
univariate time series (of the same length of x).
maximum number of lags lag.max to be passed to function VAR.
Defaults to min(4, length(x) - 1).
logical; if TRUE, it returns the plot of unconditional Granger-causality spectra on both directions with computed thresholds. Defaults to FALSE.
parameter type to be passed to function VAR.
Defaults to ''none''. Alternatives are c(''none'',''const'',''trend'').
parameter p to be passed to function VAR.
Defaults to 0.
number of bootstrap series to be computed by function tsbootstrap
of package tseries. It defaults to 1000.
prescribed confidence level. It defaults to 0.95.
matrix containing previously simulated bootstrap series, having as rows
time points, as columns variables x and y (in this order). It defaults to NULL.
boolean equal to 1 if the stationary bootstrap of Politis and Romano (1994) is applied, 0 otherwise. It defaults to 1.
frequency: frequencies used by Fast Fourier Transform.
n: time series length.
nboots: number of bootstrap series used.
confidence_level: prescribed confidence level.
stat_yes: boolean equal to 0 if no stationary VAR
is estimated across bootstrap samples, 1 otherwise.
non_stationarity_rate: percentage of non-stationary VAR models (at
least one root larger than one) estimated on bootstrapped x and y.
delay_mean: mean number of delays of stationary VAR models estimated on x and y.
quantile_unconditional_causality_y.to.x: computed quantile of the Granger-causality
unconditional spectrum from y to x.
quantile_unconditional_causality_x.to.y: computed quantile of the Granger-causality
unconditional spectrum from x to y.
freq_y.to.x: frequencies at which the Granger-causality unconditional spectrum
from y to x exceeds the computed threshold.
freq_x.to.y: frequencies at which the Granger-causality unconditional spectrum
from x to y exceeds the computed threshold.
q_max_x: computed quantile of the Granger-causality
unconditional spectrum from y to x under Bonferroni correction.
q_max_y: computed quantile of the Granger-causality
unconditional spectrum from x to y under Bonferroni correction.
freq_max_y.to.x: frequencies at which the Granger-causality unconditional spectrum
from y to x exceeds the computed threshold under Bonferroni correction.
freq_max_x.to.y: frequencies at which the Granger-causality unconditional spectrum
from x to y exceeds the computed threshold under Bonferroni correction.
The result is returned invisibly if plot is TRUE.
Granger.inference.unconditional provides bootstrap inference for the Granger-causality
unconditional spectrum of a time series x (effect variable) respect to a time series
y (cause variable). It requires packages vars and tseries.
Politis D. N. and Romano J. P., (1994). ''The Stationary Bootstrap''. Journal of the American Statistical Association, 89, 1303--1313.
Ding, M., Chen, Y., Bressler, S.L., 2006. Granger Causality: Basic Theory and Application to Neuroscience, Chap.17. Handbook of Time Series Analysis Recent Theoretical Developments and Applications.
Farne', M., Montanari, A., 2018. A bootstrap test to detect prominent Granger-causalities across frequencies. <arXiv:1803.00374>, Submitted.
VAR and tsbootstrap.
# NOT RUN {
RealGdp.rate.ts<-euro_area_indicators[,1]
m3.rate.ts<-euro_area_indicators[,2]
inf_uncond_m3_0.95<-Granger.inference.unconditional(RealGdp.rate.ts,m3.rate.ts,nboots=10)
# }
Run the code above in your browser using DataLab