Unconditional Granger-causality spectrum was first defined in Geweke (1982).
It measures the strength of the causal link from time series y to time series x and
viceversa in the frequency domain. It needs to estimate a VAR model on x and y
by package vars. For computational details we refer to Ding et al. (2006).
Granger.unconditional(x, y, ic.chosen = "SC", max.lag = min(4,
length(x) - 1), plot = F, type.chosen = "none", p = 0)univariate time series.
univariate time series (of the same length of x).
maximum number of lags lag.max to be passed to function VAR.
Defaults to min(4, length(x) - 1).
logical; if TRUE, it returns the plot of unconditional Granger-causality spectra on both directions. Defaults to FALSE.
parameter type to be passed to function VAR.
Defaults to ''none''. Alternatives are c(''none'',''const'',''trend'').
parameter p to be passed to function VAR.
Defaults to 0.
frequency: frequencies used by Fast Fourier Transform.
n: time series length.
Unconditional_causality_y.to.x: computed unconditional Granger-causality from y to x.
Unconditional_causality_x.to.y: computed unconditional Granger-causality from x to y.
roots: the roots of the estimated VAR on x and y.
The result is returned invisibly if plot is TRUE.
Granger.unconditional calculates the Granger-causality unconditional spectrum of
a time series x (effect variable) respect to a time series y (cause variable).
It requireNamespaces package vars.
Geweke, J., 1982. Measurement of linear dependence and feedback between multiple time series. J. Am. Stat. Assoc. 77, 304--313.
Ding, M., Chen, Y., Bressler, S.L., 2006. Granger Causality: Basic Theory and Application to Neuroscience, Chap.17. Handbook of Time Series Analysis Recent Theoretical Developments and Applications.
Farne', M., Montanari, A., 2018. A bootstrap test to detect prominent Granger-causalities across frequencies. <arXiv:1803.00374>, Submitted.
VAR.
# NOT RUN {
RealGdp.rate.ts<-euro_area_indicators[,1]
m3.rate.ts<-euro_area_indicators[,2]
uncond_m3<-Granger.unconditional(RealGdp.rate.ts,m3.rate.ts,"SC",4)
# }
Run the code above in your browser using DataLab