Learn R Programming

grangers (version 0.1.0)

euro_area_indicators: Six Euro Area Monetary Indicators

Description

This data set gives thre quarterly time series of real gross domestic product, M3 aggregate, M1 aggregate, inflation rate (HICP), unemployment rate and long-term interest rate for the Euro Area from Q1,1999 to Q4,2017, according to the ECB Real Time DataBase (RTDB).

Usage

euro_area_indicators

Arguments

Format

A matrix containing as columns six quarterly time series ranging from Q1,1999 to Q4,2017.

Details

Documentation of the dataset 'euro_area_indicators'

References

Farne', M., Montanari, A., 2018. A bootstrap test to detect prominent Granger-causalities across frequencies. <arXiv:1803.00374>, Submitted.

Euro Area Real Time Database documentation. 'http://sdw.ecb.europa.eu/web/docu/rtdb_docu.pdf'