This data set gives thre quarterly time series of real gross domestic product, M3 aggregate, M1 aggregate, inflation rate (HICP), unemployment rate and long-term interest rate for the Euro Area from Q1,1999 to Q4,2017, according to the ECB Real Time DataBase (RTDB).
euro_area_indicatorsA matrix containing as columns six quarterly time series ranging from Q1,1999 to Q4,2017.
Documentation of the dataset 'euro_area_indicators'
Farne', M., Montanari, A., 2018. A bootstrap test to detect prominent Granger-causalities across frequencies. <arXiv:1803.00374>, Submitted.
Euro Area Real Time Database documentation. 'http://sdw.ecb.europa.eu/web/docu/rtdb_docu.pdf'